Interface: CommonElementOptions | Chart.js
Description: Open source HTML5 Charts for your website

# # Interface: CommonElementOptions

## # Hierarchy

- `CommonElementOptions`

  ↳ `ArcOptions`

  ↳ `LineOptions`

  ↳ `PointOptions`

## # Properties

### # backgroundColor

• backgroundColor: `Color`

#### # Defined in

index.esm.d.ts:1696
(opens new window)

### # borderColor

• borderColor: `Color`

#### # Defined in

index.esm.d.ts:1695
(opens new window)

### # borderWidth

• borderWidth: `number`

#### # Defined in

index.esm.d.ts:1694
(opens new window)